@@ -1,28 +1,21 @@
 /*
- * Copyright © 2018 Red Hat, Inc
+ * SPDX-FileCopyrightText: 2018 Red Hat Inc
  *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library. If not, see <http://www.gnu.org/licenses/>.
- *
- * Authors:
- *       Jan Grulich <jgrulich@redhat.com>
+ * SPDX-FileCopyrightText: 2018 Jan Grulich <jgrulich@redhat.com>
  */
 
 #include "screencast.h"
+#include "notificationinhibition.h"
 #include "screenchooserdialog.h"
 #include "session.h"
-#include "waylandintegration.h"
 #include "utils.h"
+#include "waylandintegration.h"
+
+#include <KConfigGroup>
+#include <KLocalizedString>
+#include <KSharedConfig>
 
 #include <QLoggingCategory>
 
@@ -37,6 +30,19 @@ ScreenCastPortal::~ScreenCastPortal()
 {
 }
 
+bool ScreenCastPortal::inhibitionsEnabled() const
+{
+    if (!WaylandIntegration::isStreamingAvailable()) {
+        return false;
+    }
+
+    auto cfg = KSharedConfig::openConfig(QStringLiteral("plasmanotifyrc"));
+
+    KConfigGroup grp(cfg, "DoNotDisturb");
+
+    return grp.readEntry("WhenScreenSharing", true);
+}
+
 uint ScreenCastPortal::CreateSession(const QDBusObjectPath &handle,
                                      const QDBusObjectPath &session_handle,
                                      const QString &app_id,
@@ -62,10 +68,12 @@ uint ScreenCastPortal::CreateSession(const QDBusObjectPath &handle,
         return 2;
     }
 
-    connect(session, &Session::closed, [] () {
+    connect(session, &Session::closed, []() {
         WaylandIntegration::stopAllStreaming();
     });
 
+    connect(WaylandIntegration::waylandIntegration(), &WaylandIntegration::WaylandIntegration::streamingStopped, session, &Session::close);
+
     return 0;
 }
 
@@ -83,7 +91,7 @@ uint ScreenCastPortal::SelectSources(const QDBusObjectPath &handle,
     qCDebug(XdgDesktopPortalKdeScreenCast) << "    app_id: " << app_id;
     qCDebug(XdgDesktopPortalKdeScreenCast) << "    options: " << options;
 
-    ScreenCastSession *session = qobject_cast<ScreenCastSession*>(Session::getSession(session_handle.path()));
+    ScreenCastSession *session = qobject_cast<ScreenCastSession *>(Session::getSession(session_handle.path()));
 
     if (!session) {
         qCWarning(XdgDesktopPortalKdeScreenCast) << "Tried to select sources on non-existing session " << session_handle.path();
@@ -94,7 +102,7 @@ uint ScreenCastPortal::SelectSources(const QDBusObjectPath &handle,
 
     // Might be also a RemoteDesktopSession
     if (session->type() == Session::RemoteDesktop) {
-        RemoteDesktopSession *remoteDesktopSession = qobject_cast<RemoteDesktopSession*>(session);
+        RemoteDesktopSession *remoteDesktopSession = qobject_cast<RemoteDesktopSession *>(session);
         if (remoteDesktopSession) {
             remoteDesktopSession->setScreenSharingEnabled(true);
         }
@@ -119,7 +127,7 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
     qCDebug(XdgDesktopPortalKdeScreenCast) << "    parent_window: " << parent_window;
     qCDebug(XdgDesktopPortalKdeScreenCast) << "    options: " << options;
 
-    ScreenCastSession *session = qobject_cast<ScreenCastSession*>(Session::getSession(session_handle.path()));
+    ScreenCastSession *session = qobject_cast<ScreenCastSession *>(Session::getSession(session_handle.path()));
 
     if (!session) {
         qCWarning(XdgDesktopPortalKdeScreenCast) << "Tried to call start on non-existing session " << session_handle.path();
@@ -146,8 +154,8 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
             }
         }
         const auto selectedWindows = screenDialog->selectedWindows();
-        for (const QByteArray &winid : selectedWindows) {
-            if (!WaylandIntegration::startStreamingWindow(winid)) {
+        for (const auto &win : selectedWindows) {
+            if (!WaylandIntegration::startStreamingWindow(win)) {
                 return 2;
             }
         }
@@ -161,6 +169,10 @@ uint ScreenCastPortal::Start(const QDBusObjectPath &handle,
 
         results.insert(QStringLiteral("streams"), streams);
 
+        if (inhibitionsEnabled()) {
+            new NotificationInhibition(app_id, i18nc("Do not disturb mode is enabled because...", "Screen sharing in progress"), session);
+        }
+
         return 0;
     }
 
